KeyPair

Struct KeyPair 

pub struct KeyPair {
    pub pk: PublicKey,
    pub sk: SecretKey,
}
A key pair.

Fields

pk: PublicKey

Public key part of the key pair.

sk: SecretKey

Secret key part of the key pair.

Implementations

Source

impl KeyPair

pub const BYTES: usize = SecretKey::BYTES

Number of bytes in a key pair.

pub fn generate() -> KeyPair

Generates a new key pair.

pub fn from_seed(seed: Seed) -> KeyPair

Generates a new key pair using a secret seed.

pub fn from_slice(bytes: &[u8]) -> Result<Self, Error>

Creates a key pair from a slice.

pub fn clamp(scalar: &mut [u8])

Clamp a scalar.

pub fn split( bytes: &[u8; 64], reduce: bool, clamp: bool, ) -> ([u8; 32], [u8; 32])

Split a serialized representation of a key pair into a secret scalar and a prefix.

pub fn validate(&self) -> Result<(), Error>

Check that the public key is valid for the secret key.

Source

impl KeyPair

pub fn from_der(der: &[u8]) -> Result<Self, Error>

Import a key pair from an OpenSSL-compatible DER file.

pub fn from_pem(pem: &str) -> Result<Self, Error>

Import a key pair from an OpenSSL-compatible PEM file.

pub fn to_pem(&self) -> String

Export a key pair as an OpenSSL-compatible PEM file.