Seed

Struct Seed 

pub struct Seed(/* private fields */);
A seed, which a key pair can be derived from.

Implementations

Source

impl Seed

pub const BYTES: usize = 32

Number of raw bytes in a seed.

pub fn new(seed: [u8; 32]) -> Self

Creates a seed from raw bytes.

pub fn from_slice(seed: &[u8]) -> Result<Self, Error>

Creates a seed from a slice.

pub fn wipe(self)

Tentatively overwrite the content of the seed with zeros.

pub fn wipe_mut(&mut self)

Overwrite the content of the seed with zeros in-place.

Source

impl Seed

pub fn generate() -> Self

Generates a random seed.